==== ============= ========= =======
kind loss_type     dmg_state value  
==== ============= ========= =======
avg  contents      no_damage 2.87250
avg  contents      ds1       1.22750
avg  contents      ds2       1.38500
avg  contents      ds3       0.91500
avg  contents      ds4       0.60000
avg  nonstructural no_damage 2.98000
avg  nonstructural ds1       1.73000
avg  nonstructural ds2       1.39500
avg  nonstructural ds3       0.62250
avg  nonstructural ds4       0.27250
avg  structural    no_damage 5.18250
avg  structural    ds1       1.01750
avg  structural    ds2       0.46250
avg  structural    ds3       0.13500
avg  structural    ds4       0.20250
std  contents      no_damage 1.20675
std  contents      ds1       0.96992
std  contents      ds2       1.04488
std  contents      ds3       0.89038
std  contents      ds4       0.73485
std  nonstructural no_damage 1.25881
std  nonstructural ds1       1.05456
std  nonstructural ds2       0.98690
std  nonstructural ds3       0.80312
std  nonstructural ds4       0.49824
std  structural    no_damage 1.32635
std  structural    ds1       0.91771
std  structural    ds2       0.68088
std  structural    ds3       0.34896
std  structural    ds4       0.42602
==== ============= ========= =======